/**
   Copyright (c) 2012 Carsten Moeller, Pinneberg, Germany. <info@osm2po.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation, either version 3 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package de.cm.osm2po.demos;

import de.cm.osm2po.logging.Log;
import de.cm.osm2po.routing.Graph;
import de.cm.osm2po.routing.RouterConstraints;
import de.cm.osm2po.routing.RouterParameters;
import de.cm.osm2po.routing.VertexRouter;

public class TrafficSignalsRouter extends VertexRouter {

    public TrafficSignalsRouter(Graph graph, Log log) {
        super(graph, log);
    }

    @Override
    public boolean traverse(int sourceId, RouterConstraints stopCriteria, RouterParameters params) {
        params.setFindShortestPath(false);  // Not supported.
        return super.traverse(sourceId, stopCriteria, params);
    }

    @Override
    protected double calcVertexCost(int vertexId) {
        double h = super.calcVertexCost(vertexId);
        int clazz = this.graph.getVertexClazzes()[vertexId];
        if (TrafficSignalsNodeTagResolver.CLAZZ_TRAFFICSIGNALS == clazz) {
            h += (1d / 60d); // Virtually wait 1 minute. Does not affect intrinsic time sum.
        }
        return h;
    }
}
